@@ -1,3 +1,7 @@
+"""
+Module for managing time points in a sequence. `TimePoint` simply manages a time point relative to some start,
+and `ActionTimePoint` manages context, sequences of actions, and execution of those actions when desired.
+"""
 import datetime
 import uuid
 import threading
@@ -206,9 +210,7 @@ class ActionTimePoint(TimePoint):
                 action_kwargs = {}
                 if action.name in kwargs:
                     action_kwargs.update(kwargs[action.name])
-                execution_logger.debug(f'executing {action.name}')
                 action(**action_kwargs)
-                execution_logger.debug(f'{action.name} complete')
             execution_logger.debug('action sequence complete')
 
     def trigger(self,
