@@ -83,8 +83,6 @@ class TestSchedulerAction(unittest.TestCase):
             ValueError,
             action
         )
-        self.assertTrue(action.error)
-        self.assertIsNotNone(action.error_details)
 
 
 class TestTrackedAction(unittest.TestCase):
@@ -97,15 +95,18 @@ class TestTrackedAction(unittest.TestCase):
         end_time = time.time()
         self.assertAlmostEqual(
             start_time,
-            tracked_action.time_started
+            tracked_action.time_started,
+            places=1,
         )
         self.assertAlmostEqual(
             end_time,
-            tracked_action.time_completed
+            tracked_action.time_completed,
+            places=1,
         )
         self.assertAlmostEqual(
             end_time - start_time,
-            tracked_action.action_duration
+            tracked_action.action_duration,
+            places=1,
         )
         self.assertEqual(
             tracked_action.name,
@@ -116,3 +117,10 @@ class TestTrackedAction(unittest.TestCase):
             one_second_return
         )
         dct = tracked_action.as_dict()  # todo more elaborate test for dict testing
+
+    def test_error_catching(self):
+        action = Action.register_action(erronious)
+        action = TrackedAction(action)
+        action()
+        self.assertTrue(action.error)
+        self.assertIsNotNone(action.error_details)
